![alt text](https://github.com/labsyspharm/cylinter/blob/master/docs/logo.png?raw=true)

# An Interactive Image Segmentation Filter for Multiplex Microscopy.

**Funding:** This work is supported by the following:

* *NIH grant U54CA225088: Systems Pharmacology of Therapeutic and Adverse Responses to Immune Checkpoint and Small Molecule Drugs*
* Ludwig Center at Harvard Medical School and the Ludwig Cancer Research Foundation

**Instructions:** https://labsyspharm.github.io/cylinter/
